@@ -16,33 +16,19 @@ from nemo.collections.asr.modules.audio_preprocessing import (
     AudioToMelSpectrogramPreprocessor,
     AudioToMFCCPreprocessor,
     CropOrPadSpectrogramAugmentation,
+    MaskedPatchAugmentation,
     SpectrogramAugmentation,
 )
 from nemo.collections.asr.modules.beam_search_decoder import BeamSearchDecoderWithLM
 from nemo.collections.asr.modules.conformer_encoder import ConformerEncoder
+from nemo.collections.asr.modules.conv_asr import (
+    ConvASRDecoder,
+    ConvASRDecoderClassification,
+    ConvASRDecoderReconstruction,
+    ConvASREncoder,
+    ECAPAEncoder,
+    ParallelConvASREncoder,
+    SpeakerDecoder,
+)
 from nemo.collections.asr.modules.lstm_decoder import LSTMDecoder
 from nemo.collections.asr.modules.rnnt import RNNTDecoder, RNNTJoint
-
-# TODO @blisc: Perhaps refactor instead of import guarding
-try:
-    from nemo.collections.asr.modules.conv_asr import (
-        ConvASRDecoder,
-        ConvASRDecoderClassification,
-        ConvASRDecoderReconstruction,
-        ConvASREncoder,
-        ECAPAEncoder,
-        ParallelConvASREncoder,
-        SpeakerDecoder,
-    )
-except ModuleNotFoundError:
-    from nemo.utils.exceptions import CheckInstall
-
-    # fmt: off
-    class ConvASRDecoder(CheckInstall): pass
-    class ConvASRDecoderClassification(CheckInstall): pass
-    class ConvASREncoder(CheckInstall): pass
-    class ECAPAEncoder(CheckInstall): pass
-    class ParallelConvASREncoder(CheckInstall): pass
-    class SpeakerDecoder(CheckInstall): pass
-    class ConvASRDecoderReconstruction(CheckInstall): pass
-    # fmt: on
