@@ -44,12 +44,11 @@ class MegatronModule(torch.nn.Module):
     for pipelining."""
 
     def __init__(self, share_word_embeddings=True):
-        super(MegatronModule, self).__init__()
-
         if not HAVE_APEX:
-            logging.warning(
+            raise ImportError(
                 "Apex was not found. Please see the NeMo README for installation instructions: https://github.com/NVIDIA/NeMo#megatron-gpt."
             )
+        super(MegatronModule, self).__init__()
 
         self.share_word_embeddings = share_word_embeddings
 
@@ -64,15 +63,14 @@ class MegatronModule(torch.nn.Module):
             return self.word_embeddings.weight
         raise Exception('word_embeddings_weight() should be ' 'called for first and last stage only')
 
-    def initialize_word_embeddings(self, init_method, vocab_size, hidden_size, pipeline_model_parallel_size=1):
+    def initialize_word_embeddings(self, init_method, vocab_size, hidden_size):
         if not self.share_word_embeddings:
             raise Exception('initialize_word_embeddings() was called but ' 'share_word_embeddings is false')
 
-        # TODO: pipeline model parallelism is not implemented in NeMo yet
         # This function just initializes the word embeddings in the final stage
         # when we are using pipeline parallelism. If we aren't using pipeline
         # parallelism there is nothing to do.
-        if pipeline_model_parallel_size == 1:
+        if parallel_state.get_pipeline_model_parallel_world_size() == 1:
             return
 
         # Parameters are shared between the word embeddings layer, and the
@@ -98,17 +96,17 @@ class MegatronModule(torch.nn.Module):
             self.word_embeddings.weight.data.fill_(0)
             self.word_embeddings.weight.shared = True
 
-        # Ensure that first and last stages have the same initial parameter
-        # values.
+    def sync_initial_word_embeddings(self):
+
         if torch.distributed.is_initialized():
             if parallel_state.is_pipeline_first_stage() or parallel_state.is_pipeline_last_stage():
                 torch.distributed.all_reduce(
                     self.word_embeddings_weight().data, group=parallel_state.get_embedding_group()
                 )
         else:
-            print(
+            logging.warning(
                 "WARNING! Distributed processes aren't initialized, so "
-                "word embeddings in the last layer are not initialized. "
+                "word embeddings in the last layer are not synchronized. "
                 "If you are just manipulating a model this is fine, but "
                 "this needs to be handled manually. If you are training "
                 "something is definitely wrong."
@@ -156,11 +154,11 @@ def float16_to_fp32(val):
 
 class Float16Module(MegatronModule):
     def __init__(self, module, precision):
-        super().__init__()
         if not HAVE_APEX:
-            logging.warning(
+            raise ImportError(
                 "Apex was not found. Please see the NeMo README for installation instructions: https://github.com/NVIDIA/NeMo#megatron-gpt."
             )
+        super().__init__()
         self.precision = precision
 
         if precision == 16:
@@ -176,7 +174,10 @@ class Float16Module(MegatronModule):
                 return val.bfloat16()
 
         else:
-            raise Exception(f'{precision} is not supported. Float16Module supports ' 'only fp16 and bf16.')
+            raise Exception(
+                f'precision {precision} is not supported. Float16Module (megatron_amp_O2) supports '
+                'only fp16 and bf16.'
+            )
 
         self.float16_converter = float16_converter
 
@@ -196,3 +197,14 @@ class Float16Module(MegatronModule):
 
     def state_dict_for_save_checkpoint(self, destination=None, prefix='', keep_vars=False):
         return self.module.state_dict_for_save_checkpoint(destination, prefix, keep_vars)
+
+    def word_embeddings_weight(self):
+        if parallel_state.is_pipeline_first_stage(ignore_virtual=True):
+            return self.module.language_model.embedding.word_embeddings.weight
+        if parallel_state.is_pipeline_last_stage(ignore_virtual=True):
+            if not self.share_word_embeddings:
+                raise Exception(
+                    'word_embeddings_weight() called for last ' 'stage, but share_word_embeddings is false'
+                )
+            return self.module.word_embeddings.weight
+        raise Exception('word_embeddings_weight() should be ' 'called for first and last stage only')
