@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import contextlib
 from typing import List, Optional
 
 import numpy as np
@@ -54,20 +54,20 @@ from nemo.utils import logging, model_utils
 
 
 class MixerTTSModel(SpectrogramGenerator, Exportable):
-    """MixerTTS pipeline."""
+    """Mixer-TTS and Mixer-TTS-X models (https://arxiv.org/abs/2110.03584) that is used to generate mel spectrogram from text."""
 
     def __init__(self, cfg: DictConfig, trainer: 'Trainer' = None):
         # Convert to Hydra 1.0 compatible DictConfig
         cfg = model_utils.convert_model_config_to_dict_config(cfg)
         cfg = model_utils.maybe_update_config_version(cfg)
 
-        # setup normalizer
+        # Setup normalizer
         self.normalizer = None
         self.text_normalizer_call = None
         self.text_normalizer_call_kwargs = {}
         self._setup_normalizer(cfg)
 
-        # setup tokenizer
+        # Setup tokenizer
         self.tokenizer = None
         self._setup_tokenizer(cfg)
         assert self.tokenizer is not None
@@ -203,7 +203,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
         mel_mask = get_mask_from_lengths(true_spect_len)
         loss = 0.0
 
-        # dur loss and metrics
+        # Dur loss and metrics
         durs_loss = F.mse_loss(pred_durs, (true_durs + 1).float().log(), reduction='none')
         durs_loss = durs_loss * text_mask.float()
         durs_loss = durs_loss.sum() / text_mask.sum()
@@ -218,14 +218,14 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
 
         pred_spect = pred_spect.transpose(1, 2)
 
-        # mel loss
+        # Mel loss
         mel_loss = F.mse_loss(pred_spect, true_spect, reduction='none').mean(dim=-2)
         mel_loss = mel_loss * mel_mask.float()
         mel_loss = mel_loss.sum() / mel_mask.sum()
 
         loss = loss + self.durs_loss_scale * durs_loss + self.mel_loss_scale * mel_loss
 
-        # aligner loss
+        # Aligner loss
         bin_loss, ctc_loss = None, None
         ctc_loss = self.forward_sum_loss(attn_logprob=attn_logprob, in_lens=true_text_len, out_lens=true_spect_len)
         loss = loss + ctc_loss
@@ -234,7 +234,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
             loss = loss + self.bin_loss_scale * bin_loss
         true_avg_pitch = average_pitch(true_pitch.unsqueeze(1), attn_hard_dur).squeeze(1)
 
-        # pitch loss
+        # Pitch loss
         pitch_loss = F.mse_loss(pred_pitch, true_avg_pitch, reduction='none')  # noqa
         pitch_loss = (pitch_loss * text_mask).sum() / text_mask.sum()
 
@@ -282,7 +282,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
 
         enc_out, enc_mask = self.encoder(text, text_mask)
 
-        # aligner
+        # Aligner
         attn_soft, attn_logprob, attn_hard, attn_hard_dur = None, None, None, None
         if spect is not None:
             attn_soft, attn_logprob, attn_hard, attn_hard_dur = self.run_aligner(
@@ -295,14 +295,14 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
                 enc_out, lm_emb, lm_emb, q_mask=enc_mask.squeeze(2), kv_mask=lm_tokens != self.lm_padding_value
             )
 
-        # duration predictor
+        # Duration predictor
         log_durs_predicted = self.duration_predictor(enc_out, enc_mask)
         durs_predicted = torch.clamp(log_durs_predicted.exp() - 1, 0)
 
-        # pitch predictor
+        # Pitch predictor
         pitch_predicted = self.pitch_predictor(enc_out, enc_mask)
 
-        # avg pitch, add pitch_emb
+        # Avg pitch, add pitch_emb
         if not self.training:
             if pitch is not None:
                 pitch = average_pitch(pitch.unsqueeze(1), attn_hard_dur).squeeze(1)
@@ -318,7 +318,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
         if self.cond_on_lm_embeddings:
             enc_out = enc_out + lm_features
 
-        # regulate length
+        # Regulate length
         len_regulated_enc_out, dec_lens = regulate_len(attn_hard_dur, enc_out)
 
         dec_out, dec_lens = self.decoder(len_regulated_enc_out, get_mask_from_lengths(dec_lens).unsqueeze(2))
@@ -352,7 +352,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
 
         enc_out, enc_mask = self.encoder(text, text_mask)
 
-        # aligner
+        # Aligner
         attn_hard_dur = None
         if use_gt_durs:
             attn_soft, attn_logprob, attn_hard, attn_hard_dur = self.run_aligner(
@@ -365,11 +365,11 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
                 enc_out, lm_emb, lm_emb, q_mask=enc_mask.squeeze(2), kv_mask=lm_tokens != self.lm_padding_value
             )
 
-        # duration predictor
+        # Duration predictor
         log_durs_predicted = self.duration_predictor(enc_out, enc_mask)
         durs_predicted = torch.clamp(log_durs_predicted.exp() - 1, 0)
 
-        # avg pitch, pitch predictor
+        # Avg pitch, pitch predictor
         if use_gt_durs and pitch is not None:
             pitch = average_pitch(pitch.unsqueeze(1), attn_hard_dur).squeeze(1)
             pitch_emb = self.pitch_emb(pitch.unsqueeze(1))
@@ -377,7 +377,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
             pitch_predicted = self.pitch_predictor(enc_out, enc_mask)
             pitch_emb = self.pitch_emb(pitch_predicted.unsqueeze(1))
 
-        # add pitch emb
+        # Add pitch emb
         enc_out = enc_out + pitch_emb.transpose(1, 2)
 
         if self.cond_on_lm_embeddings:
@@ -595,7 +595,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
     ):
         if tokens is not None:
             if tokens_len is None:
-                # it is assumed that padding is consecutive and only at the end
+                # It is assumed that padding is consecutive and only at the end
                 tokens_len = (tokens != self.tokenizer.pad).sum(dim=-1)
         else:
             if raw_texts is None:
@@ -644,9 +644,18 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
         return pred_spect
 
     def parse(self, text: str, normalize=True) -> torch.Tensor:
+        if self.training:
+            logging.warning("parse() is meant to be called in eval mode.")
         if normalize and self.text_normalizer_call is not None:
             text = self.text_normalizer_call(text, **self.text_normalizer_call_kwargs)
-        return torch.tensor(self.tokenizer.encode(text)).long().unsqueeze(0).to(self.device)
+
+        eval_phon_mode = contextlib.nullcontext()
+        if hasattr(self.tokenizer, "set_phone_prob"):
+            eval_phon_mode = self.tokenizer.set_phone_prob(prob=1.0)
+
+        with eval_phon_mode:
+            tokens = self.tokenizer.encode(text)
+        return torch.tensor(tokens).long().unsqueeze(0).to(self.device)
 
     def _loader(self, cfg):
         try:
@@ -701,6 +710,7 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
 
         return list_of_models
 
+    # Methods for model exportability
     @property
     def input_types(self):
         return {
@@ -714,6 +724,24 @@ class MixerTTSModel(SpectrogramGenerator, Exportable):
             "spect": NeuralType(('B', 'D', 'T_spec'), MelSpectrogramType()),
         }
 
+    def input_example(self, max_text_len=10, max_lm_tokens_len=10):
+        text = torch.randint(
+            low=0, high=len(self.tokenizer.tokens), size=(1, max_text_len), device=self.device, dtype=torch.long,
+        )
+
+        inputs = {'text': text}
+
+        if self.cond_on_lm_embeddings:
+            inputs['lm_tokens'] = torch.randint(
+                low=0,
+                high=self.lm_embeddings.weight.shape[0],
+                size=(1, max_lm_tokens_len),
+                device=self.device,
+                dtype=torch.long,
+            )
+
+        return (inputs,)
+
     def forward_for_export(self, text, lm_tokens=None):
         text_mask = (text != self.tokenizer_pad).unsqueeze(2)
         spect = self.infer(text=text, text_mask=text_mask, lm_tokens=lm_tokens).transpose(1, 2)
