@@ -20,7 +20,10 @@ from typing import Any, Callable, Optional
 from hydra._internal.utils import _run_hydra, get_args_parser
 from hydra.core.config_store import ConfigStore
 from hydra.types import TaskFunction
-from omegaconf import DictConfig
+from omegaconf import DictConfig, OmegaConf
+
+# multiple interpolated values in the config
+OmegaConf.register_new_resolver("multiply", lambda x, y: x * y)
 
 
 def hydra_runner(
